AdminCreateConnectionResponse class

Constructors

AdminCreateConnectionResponse({required bool active, required String appId, required String domain, required String id, required String protocol, required String provider})
const
AdminCreateConnectionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

active bool
final
appId String
final
domain String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
protocol String
final
provider String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited