ClientConfigSignupField class

Constructors

ClientConfigSignupField({String? defaultValue, String? description, required String key, required String label, List<ClientConfigSelectOption>? options, required int order, String? placeholder, required String type, ClientConfigFieldValidation? validation})
const
ClientConfigSignupField.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
label String
final
options List<ClientConfigSelectOption>?
final
order int
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
validation ClientConfigFieldValidation?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited