CloneEnvironmentResponse class
Constructors
-
CloneEnvironmentResponse({required dynamic environment, required int permissionsCloned, required Map<
String, dynamic> roleIdMap, required int rolesCloned, required int webhooksCloned}) -
const
-
CloneEnvironmentResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- environment → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- permissionsCloned → int
-
final
-
roleIdMap
→ Map<
String, dynamic> -
final
- rolesCloned → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webhooksCloned → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited