Invitation class

Constructors

Invitation({required String createdAt, required String email, required String expiresAt, required String id, required String inviterId, required String orgId, required String role, required String status})
const
Invitation.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt String
final
email String
final
expiresAt String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
inviterId String
final
orgId String
final
role String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited