ScopeValue class

Constructors

ScopeValue({required bool enforced, required String scope, String? scopeId, String? updatedAt, String? updatedBy, required String value, int? version})
const
ScopeValue.fromJson(Map<String, dynamic> json)
factory

Properties

enforced bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
final
scopeId String?
final
updatedAt String?
final
updatedBy String?
final
value String
final
version int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited