SocialProvider class

A social login provider definition.

Constructors

SocialProvider({required String id, required String name, Widget? icon})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon Widget?
Optional custom icon widget. If null, a default icon is used.
final
id String
Unique provider ID (e.g. "google", "github").
final
name String
Display name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited