UserButtonMenuItem class

A custom menu item for UserButton.

Constructors

UserButtonMenuItem({required String label, IconData? icon, required VoidCallback onTap})
Creates a UserButtonMenuItem.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData?
Optional leading icon.
final
label String
Display label.
final
onTap VoidCallback
Callback when the item is tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited