Response class
Constructors
- Response({required String appId, String? canceledAt, required String currentPeriodEnd, required String currentPeriodStart, required String id, required String planId, required String status, required String tenantId, String? trialEnd, String? trialStart})
-
const
-
Response.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appId → String
-
final
- canceledAt → String?
-
final
- currentPeriodEnd → String
-
final
- currentPeriodStart → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- planId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
- tenantId → String
-
final
- trialEnd → String?
-
final
- trialStart → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited